/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.reporter;

import java.io.File;
import java.util.Map;

import org.gfxtest.common.Configuration;
import org.gfxtest.common.ConfigurationException;
import org.gfxtest.framework.Log;



/**
 * Instance of this class contain configuration for graphics tests reporter.
 * 
 * @author Pavel Tisnovsky
 */
public class ReporterConfiguration extends Configuration
{
    /**
     * Path to reports generated by Lupic.jar.
     */
    private File inputPath;

    /**
     * Path to generated output files.
     */
    private File outputPath;

    /**
     * Constructor for this class.
     * 
     * @param args
     *            command line parameters
     * @param log
     * @throws ConfigurationException
     *             this exception is thrown in case of any configuration problem
     */
    public ReporterConfiguration(String[] args, Log log) throws ConfigurationException
    {
        super(args, log);
    }

    /**
     * Prints all configuration parameters.
     */
    @SuppressWarnings("nls")
    @Override
    protected void printParameters()
    {
        this.log.logSet("input path", this.inputPath);
        this.log.logSet("output path", this.outputPath);
    }

    /**
     * Read all command line parameters from std. args.
     */
    @Override
    protected void readCommandLineParameters(String[] args) throws ConfigurationException
    {
        Map<String, String> options = resolveAllOptions(args);
        this.inputPath = new File(getStringParameter(options, "i")); //$NON-NLS-1$
        this.outputPath = new File(getStringParameter(options, "o")); //$NON-NLS-1$
    }

    /**
     * Returns input path.
     *
     * @return input path
     */
    public File getInputPath()
    {
        return this.inputPath;
    }

    /**
     * Returns output path.
     * 
     * @return output path
     */
    public File getOutputPath()
    {
        return this.outputPath;
    }

}
