/*
  Java gfx-test framework

   Copyright (C) 2012, 2013  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;
import java.awt.image.BufferedImageOp;



import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.BITBLT)
@Transformation(Transformations.VARIOUS)
@Zoom(1)
public class BitBltBufferedImageOp extends GfxTest
{
    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltEmptyBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_BYTE_BINARY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_BYTE_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_BYTE_INDEXED}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_CUSTOM}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeCustom(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_CUSTOM, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_3BYTE_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_ARGB_PRE}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_USHORT_555_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_USHORT_565_RGB}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, rasterOp);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type {@link BufferedImage#TYPE_USHORT_GRAY}.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltDiagonalGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, rasterOp);
    }

    /**
     * Test basic BitBlt operation for buffered image containing horizontal stripes pattern
     * with type TYPE_3BYTE_BGR
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param rasterOp
     *            selected raster operation
     * @return test result status - PASSED, FAILED or ERROR
     */
    protected TestResult doBitBltHorizontalStripesBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    BufferedImageOp rasterOp)
    {
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, rasterOp);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltBufferedImageOp().runTestSuite(args);
    }
    
}
