/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;



import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test check the rendering of buffered images (so called bit block
 * transfers or Bit Blt) created by various constructors and blitted with
 * changed scale.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.SCALE)
@Transformation(Transformations.SCALE)
@Zoom(1)
public class BitBltScaleImage extends GfxTest
{
    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to a double size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one half size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one third size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to two thirds size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT *2 / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to a double size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRHScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one half size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRHScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one third size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRHScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to two thirds size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRHScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to a double size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRVScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one half size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRVScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one third size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRVScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to two thirds size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRVScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT *2 / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to a double size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one half size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one third size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two thirds size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2 / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one half size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryHScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two times size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryHScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one third size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryHScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two thirds size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryHScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one half size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryVScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two times size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryVScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one third size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryVScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two thirds size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryVScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2 / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to a double size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one half size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one third size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to two thirds size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT *2 / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to a double size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRHScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one half size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRHScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one third size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRHScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to two thirds size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRHScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to a double size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRVScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one half size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRVScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to one third size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRVScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * The image is scaled to two thirds size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRVScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT *2 / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to a double size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryScaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one half size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryScaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one third size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryScaleOneThird(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two thirds size in both dimensions.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryScaleTwoThirds(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2 / 3,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2 / 3);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one half size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryHscaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH / 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two times size in horizontal dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryHscaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH * 2,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to one half size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryVscaleOneHalf(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT / 2);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * The image is scaled to two times size in vertical dimension.
     *
     * @param image
     *            destination image for BitBlt graphics canvas
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryVscaleTwoTimes(TestImage image, Graphics2D graphics2d)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d,
                        BufferedImage.TYPE_BYTE_BINARY, CommonBitmapOperations.DEFAULT_TEST_IMAGE_WIDTH,
                        CommonBitmapOperations.DEFAULT_TEST_IMAGE_HEIGHT * 2);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltScaleImage().runTestSuite(args);
    }
}
