/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012, 2013  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;



import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.TestResult;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;



/**
 * This test check the rendering of buffered images (so called bit block
 * transfers or Bit Blt) created by various constructors. Such images are
 * rendered with explicitly set background color which should affect
 * transparent or semi-transparent images.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.BITBLT)
@Transformation(Transformations.NONE)
@Zoom(1)
public class BitBltUsingBgColor extends GfxTest
{

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltEmptyBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_3BYTE_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_ARGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_ARGB_PRE
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_BINARY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_INDEXED
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_555_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_565_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_3BYTE_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageType3ByteRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_4BYTE_ABGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageType4ByteABGRPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_ARGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_ARGB_PRE
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeIntARGBPre(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_BGR
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_BYTE_BINARY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_BYTE_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_BYTE_INDEXED
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_USHORT_555_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_USHORT_565_RGB
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_USHORT_GRAY
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @param backgroundColor
     *            background color
     * @return test result status - PASSED, FAILED or ERROR
     */
    private TestResult doBitBltDiagonalGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d,
                    Color backgroundColor)
    {
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY, backgroundColor);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType3ByteRGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGR(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageType4ByteABGRPre(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntBGR(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntRGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeIntARGBPre(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinaryBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteBinary(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteGray(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexedBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeByteIndexed(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort555RGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexedBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeByteIndexed(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort555RGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshort565RGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltCheckerBufferedImageTypeUshortGray(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for BltDiagonalGrid buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType3ByteRGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_Pre.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageType4ByteABGRPre(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.yellow);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     * Background color is set to Color.white.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeIntARGBPre(image, graphics2d, Color.white);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.black.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundBlack(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.black);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.blue.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundBlue(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.blue);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.green.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundGreen(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.green);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.cyan.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundCyan(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.cyan);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.red.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundRed(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.red);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.magenta.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundMagenta(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.magenta);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     * Background color is set to Color.yellow.
     *
     * @param image
     *            image to be used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinaryBackgroundYellow(TestImage image, Graphics2D graphics2d)
    {
        return doBitBltDiagonalCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.yellow);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltUsingBgColor().runTestSuite(args);
    }
}
