/*
  Java gfx-test framework

   Copyright (C) 2010, 2011, 2012, 2013  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Graphics2D;
import java.awt.image.BufferedImage;



import org.gfxtest.framework.CommonBitmapOperations;
import org.gfxtest.framework.GfxTest;
import org.gfxtest.framework.TestImage;
import org.gfxtest.framework.annotations.BitBltOperation;
import org.gfxtest.framework.annotations.BitBltOperations;
import org.gfxtest.framework.annotations.GraphicsPrimitive;
import org.gfxtest.framework.annotations.GraphicsPrimitives;
import org.gfxtest.framework.annotations.RenderStyle;
import org.gfxtest.framework.annotations.RenderStyles;
import org.gfxtest.framework.annotations.TestType;
import org.gfxtest.framework.annotations.TestTypes;
import org.gfxtest.framework.annotations.Transformation;
import org.gfxtest.framework.annotations.Transformations;
import org.gfxtest.framework.annotations.Zoom;
import org.gfxtest.framework.TestResult;



/**
 * This test check the rendering of buffered images (so called bit block
 * transfers or Bit Blt) created by various constructors.
 * 
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@GraphicsPrimitive(GraphicsPrimitives.COMMON_BITMAP)
@RenderStyle(RenderStyles.NORMAL)
@BitBltOperation(BitBltOperations.BITBLT)
@Transformation(Transformations.NONE)
@Zoom(1)
public class BitBltBasicTests extends GfxTest
{

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageType4ByteABGR_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltEmptyBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithEmptyImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal checker buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalCheckerBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalCheckerImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_BINARY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for grid buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type
     * TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal grid buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalGridBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalGridImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with
     * type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal stripes buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalStripesBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type
     * TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical stripes buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalStripesBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type
     * TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal stripes buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalStripesBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal color stripes buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalColorStripesBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical color stripes buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalColorStripesBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for diagonal color stripes buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltDiagonalColorStripesBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithDiagonalColorStripesImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for black and white dots pattern buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltBWDotsBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithBWDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for color dots pattern buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltColorDotsBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithColorDotsImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal grayscale gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGrayscaleGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_BYTE_INDEXED.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical grayscale gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGrayscaleGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGrayscaleGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal red gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalRedGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical red gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalRedGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalRedGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal green gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalGreenGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical green gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalGreenGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalGreenGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal blue gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalBlueGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical blue gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalBlueGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalBlueGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal cyan gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalCyanGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical cyan gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalCyanGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalCyanGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal magenta gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalMagentaGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical magenta gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalMagentaGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalMagentaGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for horizontal yellow gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltHorizontalYellowGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithHorizontalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for vertical yellow gradient buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltVerticalYellowGradientBufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithVerticalYellowGradientImage(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture1BufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture1Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture2BufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture2Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture3BufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture3Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture4BufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture4Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture5BufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture5Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_3BYTE_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageType3ByteBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_3BYTE_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageType4ByteABGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_4BYTE_ABGR_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageType4ByteABGR_PRE(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_4BYTE_ABGR_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_BINARY.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeByteBinary(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_BYTE_BINARY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image
     * with type TYPE_BYTE_INDEXED.
     * 
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeByteIndexed(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_BYTE_INDEXED);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_BYTE_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeByteGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_BYTE_GRAY);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_BGR.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeIntBGR(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_BGR);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeIntRGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeIntARGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_INT_ARGB_PRE.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeIntARGB_Pre(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_INT_ARGB_PRE);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_555_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeUshort555RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_USHORT_555_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_565_RGB.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeUshort565RGB(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_USHORT_565_RGB);
    }

    /**
     * Test basic BitBlt operation for texture RGB pattern #1 buffered image with type TYPE_USHORT_GRAY.
     *
     * @param image
     *            image used as a destination for BitBlt-type operations
     * @param graphics2d
     *            graphics canvas
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testBitBltRGBTexture6BufferedImageTypeUshortGray(TestImage image, Graphics2D graphics2d)
    {
        // create new buffered image and then perform basic BitBlt test.
        return CommonBitmapOperations.doBitBltTestWithRGBTexture6Image(image, graphics2d, BufferedImage.TYPE_USHORT_GRAY);
    }

    /**
     * Entry point to the test suite.
     *
     * @param args not used in this case
     */
    public static void main(String[] args)
    {
        new BitBltBasicTests().runTestSuite(args);
    }

}
